package com.sun.org.apache.xerces.internal.dom;

import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.NotSerializableException;
import java.io.ObjectOutputStream;
import com.sun.org.apache.xerces.internal.xs.XSValue;
import com.sun.org.apache.xerces.internal.xs.ShortList;
import com.sun.org.apache.xerces.internal.xs.XSSimpleTypeDefinition;
import com.sun.org.apache.xerces.internal.impl.xs.util.StringListImpl;
import com.sun.org.apache.xerces.internal.impl.xs.AttributePSVImpl;
import com.sun.org.apache.xerces.internal.xs.ItemPSVI;
import com.sun.org.apache.xerces.internal.xs.StringList;
import com.sun.org.apache.xerces.internal.impl.dv.ValidatedInfo;
import com.sun.org.apache.xerces.internal.xs.XSTypeDefinition;
import com.sun.org.apache.xerces.internal.xs.XSAttributeDeclaration;
import com.sun.org.apache.xerces.internal.xs.AttributePSVI;

public class PSVIAttrNSImpl extends AttrNSImpl implements AttributePSVI
{
    static final long serialVersionUID = -3241738699421018889L;
    protected XSAttributeDeclaration fDeclaration;
    protected XSTypeDefinition fTypeDecl;
    protected boolean fSpecified;
    protected ValidatedInfo fValue;
    protected short fValidationAttempted;
    protected short fValidity;
    protected StringList fErrorCodes;
    protected StringList fErrorMessages;
    protected String fValidationContext;
    
    public PSVIAttrNSImpl(CoreDocumentImpl ownerDocument, String namespaceURI, String qualifiedName, String localName) {
        super(ownerDocument, namespaceURI, qualifiedName, localName);
        this.fDeclaration = null;
        this.fTypeDecl = null;
        this.fSpecified = true;
        this.fValue = new ValidatedInfo();
        this.fValidationAttempted = 0;
        this.fValidity = 0;
        this.fErrorCodes = null;
        this.fErrorMessages = null;
        this.fValidationContext = null;
    }
    
    public PSVIAttrNSImpl(CoreDocumentImpl ownerDocument, String namespaceURI, String qualifiedName) {
        super(ownerDocument, namespaceURI, qualifiedName);
        this.fDeclaration = null;
        this.fTypeDecl = null;
        this.fSpecified = true;
        this.fValue = new ValidatedInfo();
        this.fValidationAttempted = 0;
        this.fValidity = 0;
        this.fErrorCodes = null;
        this.fErrorMessages = null;
        this.fValidationContext = null;
    }
    
    @Override
    public ItemPSVI constant() {
        return new AttributePSVImpl(true, this);
    }
    
    @Override
    public boolean isConstant() {
        return false;
    }
    
    @Override
    public String getSchemaDefault() {
        return (this.fDeclaration == null) ? null : this.fDeclaration.getConstraintValue();
    }
    
    @Deprecated
    @Override
    public String getSchemaNormalizedValue() {
        return this.fValue.getNormalizedValue();
    }
    
    @Override
    public boolean getIsSchemaSpecified() {
        return this.fSpecified;
    }
    
    @Override
    public short getValidationAttempted() {
        return this.fValidationAttempted;
    }
    
    @Override
    public short getValidity() {
        return this.fValidity;
    }
    
    @Override
    public StringList getErrorCodes() {
        if (this.fErrorCodes != null) {
            return this.fErrorCodes;
        }
        return StringListImpl.EMPTY_LIST;
    }
    
    @Override
    public StringList getErrorMessages() {
        if (this.fErrorMessages != null) {
            return this.fErrorMessages;
        }
        return StringListImpl.EMPTY_LIST;
    }
    
    @Override
    public String getValidationContext() {
        return this.fValidationContext;
    }
    
    @Override
    public XSTypeDefinition getTypeDefinition() {
        return this.fTypeDecl;
    }
    
    @Override
    public XSSimpleTypeDefinition getMemberTypeDefinition() {
        return this.fValue.getMemberTypeDefinition();
    }
    
    @Override
    public XSAttributeDeclaration getAttributeDeclaration() {
        return this.fDeclaration;
    }
    
    public void setPSVI(AttributePSVI attr) {
        this.fDeclaration = attr.getAttributeDeclaration();
        this.fValidationContext = attr.getValidationContext();
        this.fValidity = attr.getValidity();
        this.fValidationAttempted = attr.getValidationAttempted();
        this.fErrorCodes = attr.getErrorCodes();
        this.fErrorMessages = attr.getErrorMessages();
        this.fValue.copyFrom(attr.getSchemaValue());
        this.fTypeDecl = attr.getTypeDefinition();
        this.fSpecified = attr.getIsSchemaSpecified();
    }
    
    @Deprecated
    @Override
    public Object getActualNormalizedValue() {
        return this.fValue.getActualValue();
    }
    
    @Deprecated
    @Override
    public short getActualNormalizedValueType() {
        return this.fValue.getActualValueType();
    }
    
    @Deprecated
    @Override
    public ShortList getItemValueTypes() {
        return this.fValue.getListValueTypes();
    }
    
    @Override
    public XSValue getSchemaValue() {
        return this.fValue;
    }
    
    private void writeObject(ObjectOutputStream out) throws IOException {
        throw new NotSerializableException(this.getClass().getName());
    }
    
    private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
        throw new NotSerializableException(this.getClass().getName());
    }
}
